<html>
<head>
<link rel="stylesheet" type="text/css" href="styles/Style.css">
<script language="JavaScript" type="text/javascript" src="ajax.js"></script>
</head>
<body>
<?php
require_once("../class/class.conectar.php");
require_once("../class/class.vacaciones.php");
require_once("../class/class.usutrab.php");
require_once("../class/class.licencia.php");
require_once("../class/class.personal.php");
require_once("../class/class.descrad.php");
require_once("../class/class.descmed.php");
require_once("../class/class.jefaturas.php");
require_once("../class/class.horario.php");

$Objcon = new Conectar();
$conex = $Objcon->con();

date_default_timezone_set('UTC');
$codprogpss = unserialize(stripslashes($_POST['codprogpss'])); 
$codprogs = unserialize(stripslashes($_POST['codprogs'])); 
$aidug = unserialize(stripslashes($_POST['aidug'])); 

//personal de apoyo
$arrcodprogspa = unserialize(stripslashes($_POST['arrcodprogspa'])); 
$arridugpa = unserialize(stripslashes($_POST['arridugpa'])); 
$arridsa = unserialize(stripslashes($_POST['arridsa'])); 

$arraymes = array();
$arraymes[] = array('idmes'=>'1','mes'=>'ENERO');
$arraymes[] = array('idmes'=>'2','mes'=>'FEBRERO');
$arraymes[] = array('idmes'=>'3','mes'=>'MARZO');
$arraymes[] = array('idmes'=>'4','mes'=>'ABRIL');
$arraymes[] = array('idmes'=>'5','mes'=>'MAYO');
$arraymes[] = array('idmes'=>'6','mes'=>'JUNIO');
$arraymes[] = array('idmes'=>'7','mes'=>'JULIO');
$arraymes[] = array('idmes'=>'8','mes'=>'AGOSTO');
$arraymes[] = array('idmes'=>'9','mes'=>'SETIEMBRE');
$arraymes[] = array('idmes'=>'10','mes'=>'OCTUBRE');
$arraymes[] = array('idmes'=>'11','mes'=>'NOVIEMBRE');
$arraymes[] = array('idmes'=>'12','mes'=>'DICIEMBRE');

$idj=$_POST['idj'];
$ids=$_POST['ids'];
$anno=$_POST['anno'];
$mm=$_POST['mes'];
$idtp=$_POST['idtp'];
$nserv=$_POST['nserv'];

//echo $ids." nuestro ";
//////session_start();

//armando grupo de servicios y sus dependencias
$cad="";
$Objj = new Jefaturas();
$datosj[] = array();
$datosj1=$Objj->buscar_jefatura($conex,$idj);
$datosj2=$Objj->listar_jefatura_servicio($conex,$idj);
$datosj=array_merge($datosj1, $datosj2);
for($i=0;$i<count($datosj);$i++){
$cad = $cad."<td width='10' class='facetfilaTD' align='center' >".$datosj[$i]['abrev']."</td>";
}

$j=0;
$aa=0;
//pregunta por el mes y servicio guardado
	for($i=0;$i<count($codprogpss);$i++){
	$cod = $aidug[$j];
	$codprog = $codprogs[$j];

	//echo count($codprogpss).": la cantidad<br>";
		if(($aa+1) == (count($datosj)+1)){
		$aa=0;
		$j=$j+1;
		$cod = $aidug[$j];
		$codprog = $codprogs[$j];
		}
		
		$idserva = $datosj[$aa]['ids'];
				$Objut = new UsuarioTrabaja();
				$res_ut = array();
			if($codprogpss[$i]==1){
				$res_ut =$Objut->buscar_per_trab($conex,$cod,$anno,$mm,$idj,$idserva,$idtp);
					if(count($res_ut)==0){
					$Objut->reg_usu_trab_per($conex,$cod,$anno,$mm,$idj,$ids,$idtp,$idserva);
					}
					
				//para programar con los codigos
				//echo "servicio".$ids."<br>";
				//echo $idserva."<br>";
					if($idserva==$ids){
					$Objut->update_codprog_per($conex,$codprog,$idj,$ids,$idtp,$idserva,$anno,$mm,$cod);
					$Objua = new Personal();
					$Objua-> modifcar_codprog_per($conex,$codprog,$cod);
					}
					
					$comentario="";
					$comentario0="";
					
				
					
					//pregunta por ultimo mes del anno
					if($mm==1){
					$mmp=12;
					$annop = $anno-1;
					}else{
					$mmp=$mm-1;
					$annop = $anno;
					}
					
					//horas pendientes del mes anterior
					$Obj_pv = new Vacaciones();
					$res_pv = array();
					$res_pv =$Obj_pv->consultar_vacaciones_periodo($conex,$cod, $annop, $mmp);
					if(count($res_pv)>0){
					$Objh = new Horario();
					$hrsdemas=$Objh->sum_per_total_sin_serv($conex,$annop,$mmp,$idj,$ids,$idtp,$cod,0);
						if($hrsdemas>0){
						$comentario0 = $hrsdemas." HRS PROGRAMADAS EN ".$arraymes[$mmp-1]['mes']." ".$annop;
						}
					
					}					
					///finaliza el analisis por horas trabajadas
					
					$comentario = $comentario0;
					//pregunta por vacaciones y descanso  medico
					$Objvp = new Vacaciones();
					$res_vp = array();
					$res_vp =$Objvp->consultar_vacaciones_prog_ini($conex,$cod, $anno, $mm);
					
					//$resultsql3 = mysql_query($sqlaskvaci);
					if(count($res_vp)>0){
					 $Objvp->modificar_estado_vacaciones_mes($conex,$cod, $anno,$mm, 0, 1);					}
					
					//editar comentario
					$res_ve=array();
					$res_ve=$Objvp->listar_vacaciones_ejec_anno_mes($conex,$cod, $anno, $mm);
								
					$comentario1="";
					$a=0;
					if(count($res_ve)>0){
					for($v=0;$v<sizeof($res_ve);$v++){
					if($a>0){
					$comentario1 = $comentario1." Y DEL ".$res_ve[$v]['fecha'];
					}else{
					$comentario1 = $comentario1.$res_ve[$v]['fecha'];
					}
					$a=$a+1;
					}
					$comentario = $comentario." VACACIONES DEL ".$comentario1;					
					}
					
					//comentar descanso medico
					$Objdm = new DescansoMedico();
					$res_dm = array();
					$res_dm = $Objdm->consultar_descmed_anno_mes($conex,$cod,$anno,$mm); 
					$comentario2="";
					$a=0;
					if(count($res_dm)>0){
					for($dm=0;$dm<sizeof($res_dm);$dm++){
					if($a>0){
					$comentario2 = " Y DEL ".$comentario2;
					}else{
					$comentario2 = $comentario2.$rowdm['fecha'];
					}
					$a=$a+1;
					}
					$comentario = $comentario."DESCANSO MEDICO DEL ".$comentario2;
					}
					
					//comentar onomastico
					$Objpe = new Personal();
					$res_o = array();
					$res_o = $Objpe->ask_cumple_mes_per($conex,$mm,$cod);
					$comentario3="";
					if(count($res_o)>0){
					for($o=0;$o<sizeof($res_o);$o++){
					$comentario3 = $comentario3.$res_o[$o]['onomastico'];
					}
					$comentario = $comentario." ONOMASTICO EL DIA ".$comentario3;
					}
					
					//cambio en las licencias
					$Objl = new Licencia();
					$res_l = array();
					$res_l =$Objl->listar_licencia_per_anno_mes($conex,$cod,$anno,$mm);
					$comentario4="";
					$a=0;
					if(count($res_l)>0){
					for($l=0;$l<sizeof($res_l);$l++){
					if($a>0){
					$comentario4 = " Y ".$res_l[$l]['tipolic']." DEL ".$res_l[$l]['fecha'];
					}else{
					$comentario4 = $comentario4." ".$res_l[$l]['tipolic']." DEL ".$res_l[$l]['fecha'];
					}
					$a=$a+1;
					}
					$comentario = $comentario.$comentario4;
					}
					
					
					//descanso por radiacion
					$Objdr = new DescansoRadiacion();
					$res_dr = array();
					$res_dr =$Objdr->listar_descrad_per_anno_mes_estado($conex,$cod,$anno,$mm,0);
					if(count($res_dr)>0){
					$Objdr->modificar_estado_descrad_mes($conex,$cod,$anno,$mm,0,1);
					}
					//editar comentario
					$res_dram = array();
					$res_dram =$Objdr->listar_descrad_per_anno_mes($conex,$cod,$anno,$mm,1);
					$comentario5="";
					$a=0;
					if(count($res_dram)>0){
					for($dr=0;$dr<sizeof($res_dram);$dr++){
					if($a>0){
					$comentario5 = $comentario5." Y DEL ".$res_dram[$dr]['fecha'];
					}else{
					$comentario5 = $comentario5.$res_dram[$dr]['fecha'];
					}
					$a=$a+1;
					}
					$comentario = $comentario." DESCANSO POR RADIACION DEL ".$comentario5;
					}
					
					
					//haciendo el cambio
					$Objut2 = new UsuarioTrabaja();
					$Objut2->update_obs_per($conex,$idj,$idtp,$ids,$anno,$mm,$cod,$comentario);
							
			}elseif($codprogpss[$i]==0){
					$Objut_e = new UsuarioTrabaja();
					$Objut_e->elimina_usu_trab_per($conex,$cod,$anno,$mm,$idj,$ids,$idtp,$idserva);
			}
			$aa=$aa+1;
		
		
	}
	

//modificando el cod de prograacion del personal de apoyo
$arrcodprogspa = unserialize(stripslashes($_POST['arrcodprogspa'])); 
$arridugpa = unserialize(stripslashes($_POST['arridugpa'])); 

for($i=0;$i<count($arrcodprogspa);$i++){
$Objut = new UsuarioTrabaja();
$codprogpa = $arrcodprogspa[$i];
$ugidpa = $arridugpa[$i];
$idsa = $arridsa[$i];
$Objut->update_codprog_per($conex,$codprogpa,$idj,$idsa,$idtp,$ids,$anno,$mm,$ugidpa);
}

$idj = $idj;
$ids = $ids;
$idtp = $idtp;
$anno = $anno;
$mm = $mm;
include("listarpersonal.php");
?>
</body>
</html>
